### Name: HDPdensity
### Title: Bayesian analysis for a Hierarchical Mixture of Dirichlet
###   Process Mixture of Normals
### Aliases: HDPdensity HDPdensity.default
### Keywords: models nonparametric

### ** Examples

## Not run: 
##D 
##D     # Data
##D       data(calgb)
##D 
##D     # Prior information
##D       Z <- calgb[,1:10]
##D       mhat <- apply(Z,2,mean)
##D       v <- diag(var(Z))
##D      
##D       prior<-list(a0=1,
##D                   b0=1,
##D                   pe1=0.1,
##D                   pe0=0.1,
##D                   ae=1,
##D                   be=1,
##D                   a=mhat,
##D                   A=diag(v), 
##D                   q=15,
##D                   R=0.25*diag(v),
##D                   cc=15,
##D                   C=diag(v))
##D 
##D     # Initial state
##D       state <- NULL
##D 
##D     # MCMC parameters
##D 
##D       mcmc <- list(nburn=1000,
##D                    nsave=2000,
##D                    nskip=0,
##D                    ndisplay=100,
##D                    npredupdate=100)
##D 
##D     # Fitting the model
##D       fit1 <- HDPdensity(formula=cbind(Z1,Z2,Z3,T1,T2,B0,B1)~CTX+GM+AMOF,
##D                          study=~study,
##D                          prior=prior,
##D                          mcmc=mcmc,
##D                          state=state,
##D                          data=calgb,  
##D                          status=TRUE)
##D 
##D     # Load data for future patients (for prediction)
##D       data(calgb.pred)
##D       X <- calgb.pred 
##D 
##D     # post-process MCMC output for predictive inference
##D     # save posterior predictive simulations in z00 ... z30
##D 
##D       z10 <- predict(fit1,data.pred=X,j=1,r=0) # post prediction for study 1
##D       z20 <- predict(fit1,data.pred=X,j=2,r=0) # .. study 2
##D       z30 <- predict(fit1,data.pred=X,j=3,r=0) # .. population at large (= study 3)
##D 
##D       z11 <- predict(fit1,data.pred=X,j=1,r=1) # idiosyncratic measures study 1
##D       z21 <- predict(fit1,data.pred=X,j=2,r=1) # .. study 2
##D       z00 <- predict(fit1,data.pred=X,j=0,r=0) # common measure
##D 
##D     # covariates (and dummy responses) of future patients
##D       colnames(z00) <- c("PATIENT",colnames(X))
##D 
##D     # plot estimated density for future patients in study 1, 2 and
##D     # in population at large
##D       idx <- which(z10[,1]==1)   ## PATIENT 1
##D       options(digits=2)
##D       par(mfrow=c(2,1))          
##D 
##D     # plot prediction fo study 1,2,population
##D       plot  (density(z10[idx,8]),
##D              ylim=c(0,1.5),xlim=c(-0.5,2.5),
##D              xlab="SLOPE OF RECOVERY",bty="l",main="FUTURE PAT 1")
##D       lines (density(z20[idx,8]),type="l",col=2)
##D       lines (density(z30[idx,8]),type="l",col=3)
##D       legend(-0.5,1.5,col=1:3,legend=c("STUDY 1","STUDY 2","POPULATION"),
##D              lty=c(1,1,1),bty="n")
##D 
##D     # common and idiosyncratic measures
##D       plot (density(z00[idx,8]),type="l",col=4,lty=1,
##D             ylim=c(0,1.5),xlim=c(-0.5,2.5),
##D             xlab="SLOPE OF RECOVERY",bty="l",main="COMMON & IDIOSYNC PARTS")
##D       lines (density(z11[idx,8]),type="l",col=1,lty=2)
##D       lines (density(z21[idx,8]),type="l",col=2,lty=2)
##D       legend(1.5,1.5,col=c(1,2,4),lty=c(2,2,1),
##D              legend=c("STUDY 1 (idiosyn.)",
##D                       "STUDY 2 (idiosyn.)",
##D                       "COMMON"),bty="n")
##D 
##D     # plot estimated density for future patients in study 1, 2 and
##D     # in population at large
##D       idx <- which(z10[,1]==2)   ## PATIENT 2
##D       options(digits=2)
##D       par(mfrow=c(2,1))
##D 
##D       plot  (density(z10[idx,8]),
##D              ylim=c(0,1.5),xlim=c(-0.5,2.5),
##D              xlab="SLOPE OF RECOVERY",bty="l",main="FUTURE PAT 2")
##D       lines (density(z20[idx,8]),type="l",col=2)
##D       lines (density(z30[idx,8]),type="l",col=3)
##D       legend(-0.5,1.5,col=1:3,legend=c("STUDY 1","STUDY 2","POPULATION"),
##D              lty=c(1,1,1),bty="n")
##D 
##D       plot (density(z00[idx,8]),type="l",col=4,lty=1,
##D             ylim=c(0,1.5),xlim=c(-0.5,2.5),
##D             xlab="SLOPE OF RECOVERY",bty="l",main="COMMON & IDIOSYNC PARTS")
##D       lines (density(z11[idx,8]),type="l",col=1,lty=2)
##D       lines (density(z21[idx,8]),type="l",col=2,lty=2)
##D       legend(1.5,1.5,col=c(1,2,4),lty=c(2,2,1),
##D              legend=c("STUDY 1 (idiosyn.)",
##D                       "STUDY 2 (idiosyn.)",
##D                       "COMMON"),bty="n")
##D 
##D     # plot nadir count by covariate, for population 
##D       z2 <- z30[,3]; ctx <- z30[,9]; gm <- z30[,10]; amf <- z30[,11]
##D     # fix covariates gm (GM-CSF) and amf (aminofostine)
##D       idx <- which( (gm==-1.78) & (amf== -0.36) )
##D       boxplot(split(z2,ctx),
##D               xlab="CYCLOPHOSPHAMIDE",bty="n",ylab="NADIR COUNT")
##D 
## End(Not run)



