### Name: LDDPdensity
### Title: Bayesian analysis for a Linear Dependent Dirichlet Process
###   Mixture Model
### Aliases: LDDPdensity LDDPdensity.default
### Keywords: models nonparametric

### ** Examples

## Not run: 
##D 
##D     ########################################################## 
##D     # Simulate data from a mixture of two normal densities
##D     ##########################################################
##D       nobs <- 500
##D       y1   <-rnorm(nobs, 3,.8)
##D 
##D       ## y2 = 0.6
##D       y21 <- rnorm(nobs,1.5, 0.8)
##D       y22 <- rnorm(nobs,4.0, 0.6)
##D       u <- runif(nobs)
##D       y2 <- ifelse(u<0.6,y21,y22)
##D       y <- c(y1,y2)
##D 
##D       ## design matrix including a single factor
##D       trt <- c(rep(0,nobs),rep(1,nobs))
##D 
##D       ## design matrix for posterior predictive 
##D       xpred <- rbind(c(1,0),c(1,1))  
##D 
##D     # Prior information
##D 
##D       s <- diag(100,2)
##D       m <- rep(0,2)
##D       psiinv <- diag(1,2)
##D      
##D       prior <- list(a0=1,b0=1/5,
##D                     nu=4,
##D                     m=m,
##D                     s=s,
##D                     psiinv=psiinv,
##D                     tau1=0.01,
##D                     tau2=0.01)
##D 
##D     # Initial state
##D       state <- NULL
##D 
##D     # MCMC parameters
##D 
##D       nburn <- 500
##D       nsave <- 1000
##D       nskip <- 10
##D       ndisplay <- 100
##D       mcmc <- list(nburn=nburn,
##D                    nsave=nsave,
##D                    nskip=nskip,
##D                    ndisplay=ndisplay)
##D 
##D     # Fit the model
##D       fit1 <- LDDPdensity(y~trt,prior=prior,mcmc=mcmc,state=state,status=TRUE,
##D                           grid=seq(-1,7,length=200),xpred=xpred)
##D 
##D     # Get posterior predictive density for future observations
##D     # with design vector x0=(1,0) 
##D 
##D       plot(fit1$grid,fit1$dens[1,],type="l",xlab="Y",ylab="p",bty="l")
##D       p1 <- dnorm(fit1$grid, 3.0, 0.8)
##D       lines(fit1$grid,p1, lty=2)
##D 
##D     # ... and x0=(1,1) 
##D       plot(fit1$grid,fit1$dens[2,],type="l",xlab="Y",ylab="p",bty="l")
##D       p2 <- 0.6*dnorm(fit1$grid, 1.5, 0.8) +
##D             0.4*dnorm(fit1$grid, 4.0, 0.6) 
##D       lines(fit1$grid,p2, lty=2)
##D 
## End(Not run)



